@@ -1,4 +1,4 @@
-from ariadne_extended.resolvers import ListModelResolver, Resolver
+from ariadne_extended.resolvers import ListModelResolver, Resolver, DetailModelMixin
 from waffle import get_waffle_flag_model
 from waffle.models import Sample, Switch
 from waffle.utils import get_setting
@@ -6,7 +6,15 @@ from waffle.utils import get_setting
 from .types import query, waffle_item_interface, waffle_type
 
 
-class WaffleResolver(ListModelResolver):
+class WaffleResolver(DetailModelMixin, ListModelResolver):
+    lookup_arg = "name"
+    lookup_field = "name"
+
+    def get_object(self):
+        lookup = self.get_lookup_filter_kwargs()
+        # Waffle model get returns an empty class if not found with the used lookup name
+        return self.model.get(**lookup)
+
     def get_queryset(self):
         # Not a true QS, will ask cache for saved model objects
         return self.model.get_all()
@@ -29,18 +37,22 @@ class AllWaffleTypesResolver(Resolver):
         return Switch.get_all() + Sample.get_all() + get_waffle_flag_model().get_all()
 
 
-@waffle_item_interface.field("active")
-def resolve_flag_active(obj, info, *args, **kwargs):
-    try:
-        return obj.is_active(info.context)
-    except TypeError:
-        return obj.is_active()
+class ActiveResolver(Resolver):
+    def check(self, parent, *args, **kwargs):
+        try:
+            return parent.is_active(self.request)
+        except TypeError:
+            return parent.is_active()
 
 
 waffle_type.set_field("flags", FlagResolver.as_resolver(method="list"))
 waffle_type.set_field("switches", SwitchResolver.as_resolver(method="list"))
 waffle_type.set_field("samples", SampleResolver.as_resolver(method="list"))
 waffle_type.set_field("all", AllWaffleTypesResolver.as_resolver(method="list"))
+waffle_type.set_field("flag", FlagResolver.as_resolver(method="retrieve"))
+waffle_type.set_field("switch", SwitchResolver.as_resolver(method="retrieve"))
+waffle_type.set_field("sample", SampleResolver.as_resolver(method="retrieve"))
+waffle_item_interface.set_field("active", ActiveResolver.as_resolver(method="check"))
 query.set_field(
     "waffle",
     lambda *x: {
