@@ -1,8 +1,10 @@
+# flake8: noqa
 from .abc import Resolver
 from .mixins import (
     ListModelMixin,
     InputMixin,
     CreateModelMixin,
+    DetailModelMixin,
     UpdateModelMixin,
     DestroyModelMixin,
 )
